Module: Indis
- Defined in:
- lib/indis-arm/version.rb,
lib/indis-arm.rb,
lib/indis-arm/analyzer.rb,
lib/indis-arm/cpu_state.rb,
lib/indis-arm/code_parser.rb,
lib/indis-arm/instruction.rb,
lib/indis-arm/instruction_helper.rb,
lib/indis-arm/instruction_loader.rb,
lib/indis-arm/analyzer/bl_analyzer.rb,
lib/indis-arm/analyzer/ldr_lit_analyzer.rb
Overview
Indis framework # Copyright (C) 2012 Vladimir "Farcaller" Pouzanov [email protected] # # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU General Public License for more details. # # You should have received a copy of the GNU General Public License # along with this program. If not, see http://www.gnu.org/licenses/. #
Defined Under Namespace
Modules: ARM